@@ -13,5 +13,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .agent import Agent
-from .value_iteration import GviAgent, ValueIterationAgent, DbsValueIterationAgent
+from agent import Agent
+from value_iteration import GviAgent, ValueIterationAgent, DbsValueIterationAgent
