@@ -13,4 +13,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .env import Env, GridWorldEnv
+from env import Env, GridWorldEnv
